==> StreamDeck-Client-0.0.2a0.tar.gz: StreamDeck-Client-0.0.2a0/README.md <==
<img src="https://raw.githubusercontent.com/philliphqs/StreamDeck/main/Project/ICON_with_TEXT_compressed.png" alt="ICON_with_TEXT" width="670" height="120">

> Use any device which can run python as a streamdeck like a Raspberry Pi

An nice alternative for the Elgato StreamDeck if you want to save some money

![](https://media.discordapp.net/attachments/761721971129843712/874049796338483290/unknown.png?width=782&height=440)


## Installation

  1. Download [``StreamDeck-Server.exe``](https://github.com/philliphqs/)
  2. Press Win + R and type ``shell:startup``
  3. Put the ``StreamDeck-Server.exe`` file in the folder
  4. Restart your Computer
  5. Take your StreamDeck device and download Python 3.9 
  6. Download [``StreamDeck.zip``](https://github.com/philliphqs/)
  7. Extract ``StreamDeck.zip``
  8. Open Terminal and type ```python -m pip install dearpygui, requests```
  9. Type ```python StreamDeck-Client.py```


## Clone Repository

```sh
git clone https://github.com/philliphqs/StreamDeck.git
```

## Release History

* 0.0.1-alpha
    * Prototype

## Coming features

* 0.0.5-alpha
    * Support for phone/tablets
* 0.1.0-alpha
    * Customization of Buttons

## Meta

philliphqs – [@phillip_hqs](https://twitter.com/philliphqs) – [philliphqs@protonmail.com](mailto:philliphqs@protonmail.com)

Distributed under the MIT license. See ``LICENSE`` for more information.

[https://github.com/philliphqs/](https://github.com/philliphqs/)

## Contributing

1. Fork it (<https://github.com/philliphqs/StreamDeck/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request

==> StreamDeck-Client-0.0.3a0.tar.gz: StreamDeck-Client-0.0.3a0/README.md <==
<img src="https://raw.githubusercontent.com/philliphqs/StreamDeck/main/Project/ICON_with_TEXT_compressed.png" alt="ICON_with_TEXT" width="670" height="120">

> Use any device which can run python as a streamdeck like a Raspberry Pi

An nice alternative for the Elgato StreamDeck if you want to save some money

![](https://media.discordapp.net/attachments/761721971129843712/874049796338483290/unknown.png?width=782&height=440)


## Installation

  1. Download [``StreamDeck-Server-Setup.exe``](https://github.com/philliphqs/)
  5. Take your StreamDeck device and download Python 3.9 
  6. Download [``StreamDeck.zip``](https://github.com/philliphqs/)
  7. Extract ``StreamDeck.zip``
  8. Open Terminal and type ```python -m pip install dearpygui, requests```
  9. Type ```python StreamDeck-Client.py```


## Clone Repository

```sh
git clone https://github.com/philliphqs/StreamDeck.git
```

## Release History

* 0.0.1-alpha
    * Prototype

## Coming features

* 0.0.2-alpha
    * StreamDeck-Server
        * System Tray
        * Setup file
* 0.0.5-alpha
    * Support for phone/tablets
* 0.1.0-alpha
    * Customization of Buttons

## Meta

philliphqs – [@phillip_hqs](https://twitter.com/philliphqs) – [philliphqs@protonmail.com](mailto:philliphqs@protonmail.com)

Distributed under the MIT license. See ``LICENSE`` for more information.

[https://github.com/philliphqs/](https://github.com/philliphqs/)

## Contributing

1. Fork it (<https://github.com/philliphqs/StreamDeck/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request
